@@ -1037,11 +1037,11 @@ class Yaql(function.Function):
                 'yaql.memoryQuota': cfg.CONF.yaql.memory_quota
             }
             cls._parser = yaql.YaqlFactory().create(global_options)
+            cls._context = yaql.create_context()
         return cls._parser
 
     def __init__(self, stack, fn_name, args):
         super(Yaql, self).__init__(stack, fn_name, args)
-        self._yaql_context = yaql.create_context()
 
         if not isinstance(self.args, collections.Mapping):
             raise TypeError(_('Arguments to "%s" must be a map.') %
@@ -1079,7 +1079,8 @@ class Yaql(function.Function):
     def result(self):
         statement = self._parse(function.resolve(self._expression))
         data = function.resolve(self._data)
-        return statement.evaluate({'data': data}, self._yaql_context)
+        context = self._context.create_child_context()
+        return statement.evaluate({'data': data}, context)
 
 
 class Equals(function.Function):
