@@ -16,17 +16,25 @@
 
 set -x
 
+localrc_path=$BASE/new/devstack/localrc
 localconf=$BASE/new/devstack/local.conf
 
+echo "CEILOMETER_PIPELINE_INTERVAL=60" >> $localrc_path
+echo "HEAT_ENABLE_ADOPT_ABANDON=True" >> $localrc_path
+
 echo -e '[[post-config|$HEAT_CONF]]\n[DEFAULT]\n' >> $localconf
 
-if [ "$ENABLE_CONVERGENCE" == "true" ] ; then
-    echo -e 'convergence_engine=true\n' >> $localconf
+if [ "$DISABLE_CONVERGENCE" == "true" ] ; then
+    echo -e 'convergence_engine=false\n' >> $localconf
 fi
 
+echo -e 'stack_scheduler_hints=true\n' >> $localconf
 echo -e 'notification_driver=messagingv2\n' >> $localconf
 echo -e 'hidden_stack_tags=hidden\n' >> $localconf
 echo -e 'encrypt_parameters_and_properties=True\n' >> $localconf
+echo -e 'logging_exception_prefix=%(asctime)s.%(msecs)03d %(process)d TRACE %(name)s %(instance)s\n' >> $localconf
+# Limit the number of connections, we're overflowing mysql
+echo -e 'executor_thread_pool_size=8\n' >> $localconf
 
 echo -e '[heat_api]\nworkers=2\n' >> $localconf
 echo -e '[heat_api_cfn]\nworkers=2\n' >> $localconf
@@ -37,13 +45,9 @@ echo -e '[cache]\nenabled=True\n' >> $localconf
 echo -e '[[post-config|/etc/neutron/neutron_vpnaas.conf]]\n' >> $localconf
 echo -e '[service_providers]\nservice_provider=VPN:openswan:neutron_vpnaas.services.vpn.service_drivers.ipsec.IPsecVPNDriver:default\n' >> $localconf
 
-
-echo "[[local|localrc]]" >> $localconf
-echo "CEILOMETER_PIPELINE_INTERVAL=60" >> $localconf
-echo "HEAT_ENABLE_ADOPT_ABANDON=True" >> $localconf
 # Use the lbaas v2 namespace driver for devstack integration testing since
 # octavia uses nested vms.
 if [[ $OVERRIDE_ENABLED_SERVICES =~ "q-lbaasv2" ]]
 then
-  echo "NEUTRON_LBAAS_SERVICE_PROVIDERV2=LOADBALANCERV2:Haproxy:neutron_lbaas.drivers.haproxy.plugin_driver.HaproxyOnHostPluginDriver:default" >> $localconf
+  echo "NEUTRON_LBAAS_SERVICE_PROVIDERV2=LOADBALANCERV2:Haproxy:neutron_lbaas.drivers.haproxy.plugin_driver.HaproxyOnHostPluginDriver:default" >> $localrc_path
 fi
